using System;
using System.Linq;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using System.Threading.Tasks;

using Net8AutoSecurityExport.Data;
using Microsoft.AspNetCore.Authorization;

namespace Net8AutoSecurityExport.Controllers
{
    [Authorize]
    public partial class ExportNorthwindController : ExportController
    {
        private readonly NorthwindContext context;
        private readonly NorthwindService service;

        public ExportNorthwindController(NorthwindContext context, NorthwindService service)
        {
            this.service = service;
            this.context = context;
        }

        [HttpGet("/export/Northwind/categories/csv")]
        [HttpGet("/export/Northwind/categories/csv(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportCategoriesToCSV(string fileName = null)
        {
            return ToCSV(ApplyQuery(await service.GetCategories(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/categories/excel")]
        [HttpGet("/export/Northwind/categories/excel(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportCategoriesToExcel(string fileName = null)
        {
            return ToExcel(ApplyQuery(await service.GetCategories(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/customercustomerdemos/csv")]
        [HttpGet("/export/Northwind/customercustomerdemos/csv(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportCustomerCustomerDemosToCSV(string fileName = null)
        {
            return ToCSV(ApplyQuery(await service.GetCustomerCustomerDemos(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/customercustomerdemos/excel")]
        [HttpGet("/export/Northwind/customercustomerdemos/excel(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportCustomerCustomerDemosToExcel(string fileName = null)
        {
            return ToExcel(ApplyQuery(await service.GetCustomerCustomerDemos(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/customerdemographics/csv")]
        [HttpGet("/export/Northwind/customerdemographics/csv(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportCustomerDemographicsToCSV(string fileName = null)
        {
            return ToCSV(ApplyQuery(await service.GetCustomerDemographics(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/customerdemographics/excel")]
        [HttpGet("/export/Northwind/customerdemographics/excel(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportCustomerDemographicsToExcel(string fileName = null)
        {
            return ToExcel(ApplyQuery(await service.GetCustomerDemographics(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/customers/csv")]
        [HttpGet("/export/Northwind/customers/csv(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportCustomersToCSV(string fileName = null)
        {
            return ToCSV(ApplyQuery(await service.GetCustomers(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/customers/excel")]
        [HttpGet("/export/Northwind/customers/excel(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportCustomersToExcel(string fileName = null)
        {
            return ToExcel(ApplyQuery(await service.GetCustomers(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/employees/csv")]
        [HttpGet("/export/Northwind/employees/csv(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportEmployeesToCSV(string fileName = null)
        {
            return ToCSV(ApplyQuery(await service.GetEmployees(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/employees/excel")]
        [HttpGet("/export/Northwind/employees/excel(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportEmployeesToExcel(string fileName = null)
        {
            return ToExcel(ApplyQuery(await service.GetEmployees(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/employeeterritories/csv")]
        [HttpGet("/export/Northwind/employeeterritories/csv(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportEmployeeTerritoriesToCSV(string fileName = null)
        {
            return ToCSV(ApplyQuery(await service.GetEmployeeTerritories(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/employeeterritories/excel")]
        [HttpGet("/export/Northwind/employeeterritories/excel(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportEmployeeTerritoriesToExcel(string fileName = null)
        {
            return ToExcel(ApplyQuery(await service.GetEmployeeTerritories(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/orderdetails/csv")]
        [HttpGet("/export/Northwind/orderdetails/csv(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportOrderDetailsToCSV(string fileName = null)
        {
            return ToCSV(ApplyQuery(await service.GetOrderDetails(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/orderdetails/excel")]
        [HttpGet("/export/Northwind/orderdetails/excel(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportOrderDetailsToExcel(string fileName = null)
        {
            return ToExcel(ApplyQuery(await service.GetOrderDetails(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/orders/csv")]
        [HttpGet("/export/Northwind/orders/csv(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportOrdersToCSV(string fileName = null)
        {
            return ToCSV(ApplyQuery(await service.GetOrders(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/orders/excel")]
        [HttpGet("/export/Northwind/orders/excel(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportOrdersToExcel(string fileName = null)
        {
            return ToExcel(ApplyQuery(await service.GetOrders(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/products/csv")]
        [HttpGet("/export/Northwind/products/csv(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportProductsToCSV(string fileName = null)
        {
            return ToCSV(ApplyQuery(await service.GetProducts(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/products/excel")]
        [HttpGet("/export/Northwind/products/excel(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportProductsToExcel(string fileName = null)
        {
            return ToExcel(ApplyQuery(await service.GetProducts(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/regions/csv")]
        [HttpGet("/export/Northwind/regions/csv(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportRegionsToCSV(string fileName = null)
        {
            return ToCSV(ApplyQuery(await service.GetRegions(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/regions/excel")]
        [HttpGet("/export/Northwind/regions/excel(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportRegionsToExcel(string fileName = null)
        {
            return ToExcel(ApplyQuery(await service.GetRegions(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/shippers/csv")]
        [HttpGet("/export/Northwind/shippers/csv(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportShippersToCSV(string fileName = null)
        {
            return ToCSV(ApplyQuery(await service.GetShippers(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/shippers/excel")]
        [HttpGet("/export/Northwind/shippers/excel(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportShippersToExcel(string fileName = null)
        {
            return ToExcel(ApplyQuery(await service.GetShippers(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/suppliers/csv")]
        [HttpGet("/export/Northwind/suppliers/csv(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportSuppliersToCSV(string fileName = null)
        {
            return ToCSV(ApplyQuery(await service.GetSuppliers(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/suppliers/excel")]
        [HttpGet("/export/Northwind/suppliers/excel(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportSuppliersToExcel(string fileName = null)
        {
            return ToExcel(ApplyQuery(await service.GetSuppliers(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/territories/csv")]
        [HttpGet("/export/Northwind/territories/csv(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportTerritoriesToCSV(string fileName = null)
        {
            return ToCSV(ApplyQuery(await service.GetTerritories(), Request.Query, false), fileName);
        }

        [HttpGet("/export/Northwind/territories/excel")]
        [HttpGet("/export/Northwind/territories/excel(fileName='{fileName}')")]
        public async Task<FileStreamResult> ExportTerritoriesToExcel(string fileName = null)
        {
            return ToExcel(ApplyQuery(await service.GetTerritories(), Request.Query, false), fileName);
        }
    }
}
